@@ -9,8 +9,8 @@
 """Unittest cases for testing the icon theme provider interface"""
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testTheme.py 65165 2010-08-02 22:04:37Z CJP $"
-__revision__ = "$Revision: 65165 $"
+__svnid__ = "$Id: testTheme.py 69212 2011-09-28 18:47:44Z CJP $"
+__revision__ = "$Revision: 69212 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -62,3 +62,20 @@ class ThemeTest(unittest.TestCase):
         # Try for non existant bitmap
         bmp = self.bmpprov.GetBitmap(-1, wx.ART_MENU)
         self.assertTrue(bmp.IsNull())
+
+    def testLibrary(self):
+        """Test all library resources"""
+        # Test all art resources
+        bad = list()
+        for artid, res in ed_theme.ART.iteritems():
+            if artid in (ed_glob.ID_ZOOM_IN,
+                         ed_glob.ID_ZOOM_OUT,
+                         ed_glob.ID_ZOOM_NORMAL,
+                         ed_glob.ID_SAVEALL):
+                continue # special case for some themes (not in default)
+
+            bmp = self.bmpprov.GetBitmap(artid, wx.ART_MENU)
+            if not bmp.IsOk():
+                bad.append(res)
+        if len(bad):
+            self.assertFalse(True, "Bad resources: %s" % repr(bad))
